@@ -9,7 +9,7 @@
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; under version 2 of the License.
+ *  the Free Software Foundation; under version 3 of the License.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -17,8 +17,10 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses>.
+ *
+ *  The Audacious team does not consider modular code linking to
+ *  Audacious or using our public API to be a derived work.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -35,7 +37,7 @@
 #include <string.h>
 
 #include "platform/smartinclude.h"
-#include "widgets/widgetcore.h"
+#include "skin.h"
 #include "dock.h"
 #include "hints.h"
 #include "input.h"
@@ -53,6 +55,10 @@
 #include "images/audacious_eq.xpm"
 
 #include "ui_skinned_window.h"
+#include "ui_skinned_button.h"
+#include "ui_skinned_horizontal_slider.h"
+#include "ui_skinned_equalizer_slider.h"
+#include "ui_skinned_equalizer_graph.h"
 
 enum PresetViewCols {
     PRESET_VIEW_COL_NAME,
@@ -68,6 +74,7 @@ typedef struct _EqualizerPreset EqualizerPreset;
 
 
 GtkWidget *equalizerwin;
+GtkWidget *equalizerwin_graph;
 
 static GtkWidget *equalizerwin_load_window = NULL;
 static GtkWidget *equalizerwin_load_auto_window = NULL;
@@ -78,21 +85,14 @@ static GtkWidget *equalizerwin_save_auto_entry = NULL;
 static GtkWidget *equalizerwin_delete_window = NULL;
 static GtkWidget *equalizerwin_delete_auto_window = NULL;
 
-static GdkPixmap *equalizerwin_bg, *equalizerwin_bg_x2;
+static GtkWidget *equalizerwin_on, *equalizerwin_auto;
 
-static GList *equalizerwin_wlist = NULL;
-
-static TButton *equalizerwin_on, *equalizerwin_auto;
-
-static PButton *equalizerwin_presets, *equalizerwin_shade;
-PButton *equalizerwin_close;
-static EqGraph *equalizerwin_graph;
-static EqSlider *equalizerwin_preamp, *equalizerwin_bands[10];
-static HSlider *equalizerwin_volume, *equalizerwin_balance;
+static GtkWidget *equalizerwin_close, *equalizerwin_presets, *equalizerwin_shade;
+static GtkWidget *equalizerwin_preamp,*equalizerwin_bands[10];
+static GtkWidget *equalizerwin_volume, *equalizerwin_balance;
 
 static GList *equalizer_presets = NULL, *equalizer_auto_presets = NULL;
 
-
 EqualizerPreset *
 equalizer_preset_new(const gchar * name)
 {
@@ -140,15 +140,16 @@ equalizerwin_set_doublesize(gboolean ds)
 
     if (ds) {
         dock_window_resize(GTK_WINDOW(equalizerwin), 550, height * 2, 550, height * 2);
-        gdk_window_set_back_pixmap(equalizerwin->window, equalizerwin_bg_x2,
-                                   0);
-    }
-    else {
+    } else {
         dock_window_resize(GTK_WINDOW(equalizerwin), 275, height, 275, height);
-        gdk_window_set_back_pixmap(equalizerwin->window, equalizerwin_bg, 0);
     }
 
-    draw_equalizer_window(TRUE);
+    GList *iter;
+    for (iter = GTK_FIXED (SKINNED_WINDOW(equalizerwin)->fixed)->children; iter; iter = g_list_next (iter)) {
+        GtkFixedChild *child_data = (GtkFixedChild *) iter->data;
+        GtkWidget *child = child_data->widget;
+        g_signal_emit_by_name(child, "toggle-double-size");
+    }
 }
 
 void
@@ -161,25 +162,23 @@ equalizerwin_set_shade_menu_cb(gboolean shaded)
     if (shaded) {
         dock_shade(dock_window_list, GTK_WINDOW(equalizerwin),
                    14 * (EQUALIZER_DOUBLESIZE + 1));
-        pbutton_set_button_data(equalizerwin_shade, -1, 3, -1, 47);
-        pbutton_set_skin_index1(equalizerwin_shade, SKIN_EQ_EX);
-        pbutton_set_button_data(equalizerwin_close, 11, 38, 11, 47);
-        pbutton_set_skin_index(equalizerwin_close, SKIN_EQ_EX);
-        widget_show(WIDGET(equalizerwin_volume));
-        widget_show(WIDGET(equalizerwin_balance));
+        ui_skinned_set_push_button_data(equalizerwin_shade, -1, 3, -1, 47);
+        ui_skinned_button_set_skin_index1(equalizerwin_shade, SKIN_EQ_EX);
+        ui_skinned_set_push_button_data(equalizerwin_close, 11, 38, 11, 47);
+        ui_skinned_button_set_skin_index(equalizerwin_close, SKIN_EQ_EX);
+        gtk_widget_show(equalizerwin_volume);
+        gtk_widget_show(equalizerwin_balance);
     }
     else {
         dock_shade(dock_window_list, GTK_WINDOW(equalizerwin),
                    116 * (EQUALIZER_DOUBLESIZE + 1));
-        pbutton_set_button_data(equalizerwin_shade, -1, 137, -1, 38);
-        pbutton_set_skin_index1(equalizerwin_shade, SKIN_EQMAIN);
-        pbutton_set_button_data(equalizerwin_close, 0, 116, 0, 125);
-        pbutton_set_skin_index(equalizerwin_close, SKIN_EQMAIN);
-        widget_hide(WIDGET(equalizerwin_volume));
-        widget_hide(WIDGET(equalizerwin_balance));
+        ui_skinned_set_push_button_data(equalizerwin_shade, -1, 137, -1, 38);
+        ui_skinned_button_set_skin_index1(equalizerwin_shade, SKIN_EQMAIN);
+        ui_skinned_set_push_button_data(equalizerwin_close, 0, 116, 0, 125);
+        ui_skinned_button_set_skin_index(equalizerwin_close, SKIN_EQMAIN);
+        gtk_widget_hide(equalizerwin_volume);
+        gtk_widget_hide(equalizerwin_balance);
     }
-
-    draw_equalizer_window(TRUE);
 }
 
 static void
@@ -208,9 +207,9 @@ equalizerwin_eq_changed(void)
 {
     gint i;
 
-    cfg.equalizer_preamp = eqslider_get_position(equalizerwin_preamp);
+    cfg.equalizer_preamp = ui_skinned_equalizer_slider_get_position(equalizerwin_preamp);
     for (i = 0; i < 10; i++)
-        cfg.equalizer_bands[i] = eqslider_get_position(equalizerwin_bands[i]);
+        cfg.equalizer_bands[i] = ui_skinned_equalizer_slider_get_position(equalizerwin_bands[i]);
     /* um .. i think we need both of these for xmms compatibility ..
        not sure. -larne */
     input_set_eq(cfg.equalizer_active, cfg.equalizer_preamp,
@@ -218,13 +217,13 @@ equalizerwin_eq_changed(void)
     output_set_eq(cfg.equalizer_active, cfg.equalizer_preamp,
                   cfg.equalizer_bands);
 
-    widget_draw(WIDGET(equalizerwin_graph));
+    gtk_widget_queue_draw(equalizerwin_graph);
 }
 
 static void
-equalizerwin_on_pushed(gboolean toggled)
+equalizerwin_on_pushed(void)
 {
-    cfg.equalizer_active = toggled;
+    cfg.equalizer_active = UI_SKINNED_BUTTON(equalizerwin_on)->inside;
     equalizerwin_eq_changed();
 }
 
@@ -239,105 +238,17 @@ equalizerwin_presets_pushed(void)
 }
 
 static void
-equalizerwin_auto_pushed(gboolean toggled)
+equalizerwin_auto_pushed(void)
 {
-    cfg.equalizer_autoload = toggled;
-}
-
-void
-draw_equalizer_window(gboolean force)
-{
-    GdkImage *img, *img2;
-    GList *wl;
-    Widget *w;
-    gboolean redraw;
-
-    widget_list_lock(equalizerwin_wlist);
-
-    if (force) {
-        skin_draw_pixmap(bmp_active_skin, equalizerwin_bg, SKINNED_WINDOW(equalizerwin)->gc,
-                         SKIN_EQMAIN, 0, 0, 0, 0, 275, 116);
-        if (gtk_window_has_toplevel_focus(GTK_WINDOW(equalizerwin)) ||
-            !cfg.dim_titlebar) {
-            if (!cfg.equalizer_shaded)
-                skin_draw_pixmap(bmp_active_skin, equalizerwin_bg,
-                                 SKINNED_WINDOW(equalizerwin)->gc, SKIN_EQMAIN, 0, 134, 0,
-                                 0, 275, 14);
-            else
-                skin_draw_pixmap(bmp_active_skin, equalizerwin_bg,
-                                 SKINNED_WINDOW(equalizerwin)->gc, SKIN_EQ_EX, 0, 0, 0, 0,
-                                 275, 14);
-        }
-        else {
-            if (!cfg.equalizer_shaded)
-                skin_draw_pixmap(bmp_active_skin, equalizerwin_bg,
-                                 SKINNED_WINDOW(equalizerwin)->gc, SKIN_EQMAIN, 0, 149, 0,
-                                 0, 275, 14);
-            else
-                skin_draw_pixmap(bmp_active_skin, equalizerwin_bg,
-                                 SKINNED_WINDOW(equalizerwin)->gc, SKIN_EQ_EX, 0, 15, 0, 0,
-                                 275, 14);
-
-        }
-    }
-
-    widget_list_draw(equalizerwin_wlist, &redraw, force);
-
-    if (force || redraw) {
-        if (cfg.doublesize && cfg.eq_doublesize_linked) {
-            if (force) {
-                img = gdk_drawable_get_image(equalizerwin_bg, 0, 0, 275, 116);
-                img2 = create_dblsize_image(img);
-                gdk_draw_image(equalizerwin_bg_x2, SKINNED_WINDOW(equalizerwin)->gc,
-                               img2, 0, 0, 0, 0, 550, 232);
-                g_object_unref(img2);
-                g_object_unref(img);
-            }
-            else {
-                for (wl = equalizerwin_wlist; wl; wl = g_list_next(wl)) {
-                    w = WIDGET(wl->data);
-                    if (w->redraw && w->visible) {
-                        img = gdk_drawable_get_image(equalizerwin_bg,
-                                                     w->x, w->y,
-                                                     w->width, w->height);
-                        img2 = create_dblsize_image(img);
-                        gdk_draw_image(equalizerwin_bg_x2,
-                                       SKINNED_WINDOW(equalizerwin)->gc, img2, 0, 0,
-                                       w->x << 1, w->y << 1, w->width << 1,
-                                       w->height << 1);
-                        g_object_unref(img2);
-                        g_object_unref(img);
-                        w->redraw = FALSE;
-                    }
-                }
-            }
-        }
-        else
-            widget_list_clear_redraw(equalizerwin_wlist);
-        gdk_window_clear(equalizerwin->window);
-        gdk_flush();
-    }
-
-    widget_list_unlock(equalizerwin_wlist);
+    cfg.equalizer_autoload = UI_SKINNED_BUTTON(equalizerwin_auto)->inside;
 }
 
 gboolean
 equalizerwin_press(GtkWidget * widget, GdkEventButton * event,
                    gpointer callback_data)
 {
-    gint mx, my;
-    gboolean grab = TRUE;
-
-    mx = event->x;
-    my = event->y;
-    if (cfg.doublesize && cfg.eq_doublesize_linked) {
-        event->x /= 2;
-        event->y /= 2;
-    }
-
     if (event->button == 1 && event->type == GDK_BUTTON_PRESS &&
-        ((cfg.easy_move || cfg.equalizer_shaded || event->y < 14) &&
-         !ui_skinned_window_widgetlist_contained(equalizerwin, event->x, event->y))) {
+        (cfg.easy_move || cfg.equalizer_shaded || event->y < 14)) {
          equalizerwin_raise();
          dock_move_press(dock_window_list, GTK_WINDOW(equalizerwin), event,
                          FALSE);
@@ -348,58 +259,14 @@ equalizerwin_press(GtkWidget * widget, GdkEventButton * event,
         if (dock_is_moving(GTK_WINDOW(equalizerwin)))
             dock_move_release(GTK_WINDOW(equalizerwin));
     }
-    else if (event->button == 3 &&
-             !(widget_contains(WIDGET(equalizerwin_on), event->x, event->y) ||
-               widget_contains(WIDGET(equalizerwin_auto), event->x, event->y))) {
+    else if (event->button == 3) {
         /*
          * Pop up the main menu a few pixels down to avoid
          * anything to be selected initially.
          */
        ui_manager_popup_menu_show(GTK_MENU(mainwin_general_menu), event->x_root,
                                 event->y_root + 2, 3, event->time);
-        grab = FALSE;
     }
-    else {
-        handle_press_cb(equalizerwin_wlist, widget, event);
-        draw_equalizer_window(FALSE);
-    }
-    if (grab)
-        gdk_pointer_grab(GDK_WINDOW(equalizerwin->window), FALSE,
-                         GDK_BUTTON_MOTION_MASK | GDK_BUTTON_RELEASE_MASK,
-                         NULL, NULL, GDK_CURRENT_TIME);
-
-    return FALSE;
-}
-
-static void
-equalizerwin_scroll(GtkWidget * widget, GdkEventScroll * event, gpointer data)
-{
-    if (cfg.doublesize && cfg.eq_doublesize_linked) {
-        event->x /= 2;
-        event->y /= 2;
-    }
-
-    handle_scroll_cb(equalizerwin_wlist, widget, event);
-    draw_equalizer_window(FALSE);
-}
-
-static gboolean
-equalizerwin_motion(GtkWidget * widget,
-                    GdkEventMotion * event, gpointer callback_data)
-{
-    GdkEvent *gevent;
-
-    if (cfg.doublesize && cfg.eq_doublesize_linked) {
-        event->x /= 2;
-        event->y /= 2;
-    }
-
-    handle_motion_cb(equalizerwin_wlist, widget, event);
-    draw_equalizer_window(FALSE);
-
-    gdk_flush();
-
-    while ((gevent = gdk_event_get()) != NULL) gdk_event_free(gevent);
 
     return FALSE;
 }
@@ -408,51 +275,26 @@ static gboolean
 equalizerwin_release(GtkWidget * widget,
                      GdkEventButton * event, gpointer callback_data)
 {
-    gdk_pointer_ungrab(GDK_CURRENT_TIME);
-    gdk_flush();
-
-    if (cfg.doublesize && cfg.eq_doublesize_linked) {
-        event->x /= 2;
-        event->y /= 2;
-    }
     if (dock_is_moving(GTK_WINDOW(equalizerwin))) {
         dock_move_release(GTK_WINDOW(equalizerwin));
     }
-    else {
-        handle_release_cb(equalizerwin_wlist, widget, event);
-        draw_equalizer_window(FALSE);
-    }
 
     return FALSE;
 }
 
-static gboolean
-equalizerwin_focus_in(GtkWidget * widget,
-                      GdkEvent * event,
-                      gpointer data)
-{
-    equalizerwin_close->pb_allow_draw = TRUE;
-    equalizerwin_shade->pb_allow_draw = TRUE;
-    draw_equalizer_window(TRUE);
-    return TRUE;
-}
-
-static gboolean
-equalizerwin_focus_out(GtkWidget * widget,
-                       GdkEventButton * event,
-                       gpointer data)
-{
-    equalizerwin_close->pb_allow_draw = FALSE;
-    equalizerwin_shade->pb_allow_draw = FALSE;
-    draw_equalizer_window(TRUE);
-    return TRUE;
-}
-
 static gboolean
 equalizerwin_keypress(GtkWidget * widget,
                       GdkEventKey * event,
                       gpointer data)
 {
+    if (event->keyval == GDK_Tab && event->state & GDK_CONTROL_MASK) {
+        if (cfg.playlist_visible)
+            gtk_window_present(GTK_WINDOW(playlistwin));
+        else if (cfg.player_visible)
+            gtk_window_present(GTK_WINDOW(mainwin));
+        return TRUE;
+    }
+
     if (!cfg.equalizer_shaded) {
         gtk_widget_event(mainwin, (GdkEvent *) event);
         return TRUE;
@@ -475,30 +317,6 @@ equalizerwin_keypress(GtkWidget * widget,
     return FALSE;
 }
 
-static gboolean
-equalizerwin_configure(GtkWidget * window,
-                       GdkEventConfigure * event,
-                       gpointer data)
-{
-    if (!GTK_WIDGET_VISIBLE(window))
-        return FALSE;
-
-    cfg.equalizer_x = event->x;
-    cfg.equalizer_y = event->y;
-    return FALSE;
-}
-
-static void
-equalizerwin_set_back_pixmap(void)
-{
-    if (cfg.doublesize && cfg.eq_doublesize_linked)
-        gdk_window_set_back_pixmap(equalizerwin->window, equalizerwin_bg_x2,
-                                   0);
-    else
-        gdk_window_set_back_pixmap(equalizerwin->window, equalizerwin_bg, 0);
-    gdk_window_clear(equalizerwin->window);
-}
-
 static void
 equalizerwin_close_cb(void)
 {
@@ -522,13 +340,23 @@ equalizerwin_read_presets(const gchar * basename)
     gint i, p = 0;
     EqualizerPreset *preset;
 
+    /* START mod: add check for the default presets locate in system path ({prefix}/share/audacious)
+       by Massimo Cavalleri (submax) */
+
     filename = g_build_filename(bmp_paths[BMP_PATH_USER_DIR], basename, NULL);
 
     if ((rcfile = bmp_rcfile_open(filename)) == NULL) {
         g_free(filename);
-        return NULL;
+        // DATA_DIR = "{prefix}/share/audacious" ; example is "/usr/share/audacious"
+        filename = g_build_filename(DATA_DIR, basename, NULL);
+        if ((rcfile = bmp_rcfile_open(filename)) == NULL) {
+           g_free(filename);
+           return NULL;
+        }
     }
 
+    // END mod
+
     g_free(filename);
 
     for (;;) {
@@ -558,21 +386,22 @@ gint
 equalizerwin_volume_frame_cb(gint pos)
 {
     if (equalizerwin_volume) {
+        gint x;
         if (pos < 32)
-            equalizerwin_volume->hs_knob_nx =
-                equalizerwin_volume->hs_knob_px = 1;
+            x = 1;
         else if (pos < 63)
-            equalizerwin_volume->hs_knob_nx =
-                equalizerwin_volume->hs_knob_px = 4;
+            x = 4;
         else
-            equalizerwin_volume->hs_knob_nx =
-                equalizerwin_volume->hs_knob_px = 7;
+            x = 7;
+
+        UI_SKINNED_HORIZONTAL_SLIDER(equalizerwin_volume)->knob_nx = x;
+        UI_SKINNED_HORIZONTAL_SLIDER(equalizerwin_volume)->knob_px = x;
     }
     return 1;
 }
 
 static void
-equalizerwin_volume_motion_cb(gint pos)
+equalizerwin_volume_motion_cb(GtkWidget *widget, gint pos)
 {
     gint v = (gint) rint(pos * 100 / 94.0);
     mainwin_adjust_volume_motion(v);
@@ -580,7 +409,7 @@ equalizerwin_volume_motion_cb(gint pos)
 }
 
 static void
-equalizerwin_volume_release_cb(gint pos)
+equalizerwin_volume_release_cb(GtkWidget *widget, gint pos)
 {
     mainwin_adjust_volume_release();
 }
@@ -589,22 +418,23 @@ static gint
 equalizerwin_balance_frame_cb(gint pos)
 {
     if (equalizerwin_balance) {
+        gint x;
         if (pos < 13)
-            equalizerwin_balance->hs_knob_nx =
-                equalizerwin_balance->hs_knob_px = 11;
+            x = 11;
         else if (pos < 26)
-            equalizerwin_balance->hs_knob_nx =
-                equalizerwin_balance->hs_knob_px = 14;
+            x = 14;
         else
-            equalizerwin_balance->hs_knob_nx =
-                equalizerwin_balance->hs_knob_px = 17;
+            x = 17;
+
+        UI_SKINNED_HORIZONTAL_SLIDER(equalizerwin_balance)->knob_nx = x;
+        UI_SKINNED_HORIZONTAL_SLIDER(equalizerwin_balance)->knob_px = x;
     }
 
     return 1;
 }
 
 static void
-equalizerwin_balance_motion_cb(gint pos)
+equalizerwin_balance_motion_cb(GtkWidget *widget, gint pos)
 {
     gint b;
     pos = MIN(pos, 38);         /* The skin uses a even number of pixels
@@ -615,7 +445,7 @@ equalizerwin_balance_motion_cb(gint pos)
 }
 
 static void
-equalizerwin_balance_release_cb(gint pos)
+equalizerwin_balance_release_cb(GtkWidget *widget, gint pos)
 {
     mainwin_adjust_balance_release();
 }
@@ -623,14 +453,14 @@ equalizerwin_balance_release_cb(gint pos)
 void
 equalizerwin_set_balance_slider(gint percent)
 {
-    hslider_set_position(equalizerwin_balance,
+    ui_skinned_horizontal_slider_set_position(equalizerwin_balance,
                          (gint) rint((percent * 19 / 100.0) + 19));
 }
 
 void
 equalizerwin_set_volume_slider(gint percent)
 {
-    hslider_set_position(equalizerwin_volume,
+    ui_skinned_horizontal_slider_set_position(equalizerwin_volume,
                          (gint) rint(percent * 94 / 100.0));
 }
 
@@ -639,97 +469,59 @@ equalizerwin_create_widgets(void)
 {
     gint i;
 
-    equalizerwin_on =
-        create_tbutton(&equalizerwin_wlist, equalizerwin_bg,
-                       SKINNED_WINDOW(equalizerwin)->gc, 14, 18, 25, 12, 10, 119, 128, 119,
-                       69, 119, 187, 119, equalizerwin_on_pushed,
-                       SKIN_EQMAIN);
-    tbutton_set_toggled(equalizerwin_on, cfg.equalizer_active);
-    ui_skinned_window_widgetlist_associate(equalizerwin, 
-        WIDGET(equalizerwin_on));
+    equalizerwin_on = ui_skinned_button_new();
+    ui_skinned_toggle_button_setup(equalizerwin_on, SKINNED_WINDOW(equalizerwin)->fixed,
+                                   14, 18, 25, 12, 10, 119, 128, 119, 69, 119, 187, 119, SKIN_EQMAIN);
+    g_signal_connect(equalizerwin_on, "clicked", equalizerwin_on_pushed, NULL);
+    UI_SKINNED_BUTTON(equalizerwin_on)->inside = cfg.equalizer_active;
 
-    equalizerwin_auto =
-        create_tbutton(&equalizerwin_wlist, equalizerwin_bg,
-                       SKINNED_WINDOW(equalizerwin)->gc, 39, 18, 33, 12, 35, 119, 153, 119,
-                       94, 119, 212, 119, equalizerwin_auto_pushed,
-                       SKIN_EQMAIN);
-    tbutton_set_toggled(equalizerwin_auto, cfg.equalizer_autoload);
-    ui_skinned_window_widgetlist_associate(equalizerwin, 
-        WIDGET(equalizerwin_auto));
+    equalizerwin_auto = ui_skinned_button_new();
+    ui_skinned_toggle_button_setup(equalizerwin_auto, SKINNED_WINDOW(equalizerwin)->fixed,
+                                   39, 18, 33, 12, 35, 119, 153, 119, 94, 119, 212, 119, SKIN_EQMAIN);
+    g_signal_connect(equalizerwin_auto, "clicked", equalizerwin_auto_pushed, NULL);
+    UI_SKINNED_BUTTON(equalizerwin_auto)->inside = cfg.equalizer_autoload;
 
-    equalizerwin_presets =
-        create_pbutton(&equalizerwin_wlist, equalizerwin_bg,
-                       SKINNED_WINDOW(equalizerwin)->gc, 217, 18, 44, 12, 224, 164, 224,
-                       176, equalizerwin_presets_pushed, SKIN_EQMAIN);
-    ui_skinned_window_widgetlist_associate(equalizerwin, 
-        WIDGET(equalizerwin_presets));
+    equalizerwin_presets = ui_skinned_button_new();
+    ui_skinned_push_button_setup(equalizerwin_presets, SKINNED_WINDOW(equalizerwin)->fixed,
+                                 217, 18, 44, 12, 224, 164, 224, 176, SKIN_EQMAIN);
+    g_signal_connect(equalizerwin_presets, "clicked", equalizerwin_presets_pushed, NULL );
 
-    equalizerwin_close =
-        create_pbutton(&equalizerwin_wlist, equalizerwin_bg,
-                       SKINNED_WINDOW(equalizerwin)->gc, 264, 3, 9, 9, 0, 116, 0, 125,
-                       equalizerwin_close_cb, SKIN_EQMAIN);
-    equalizerwin_close->pb_allow_draw = FALSE;
-    ui_skinned_window_widgetlist_associate(equalizerwin, 
-        WIDGET(equalizerwin_close));
+    equalizerwin_close = ui_skinned_button_new();
+    ui_skinned_push_button_setup(equalizerwin_close, SKINNED_WINDOW(equalizerwin)->fixed,
+                                 264, 3, 9, 9, 0, 116, 0, 125, SKIN_EQMAIN);
+    g_signal_connect(equalizerwin_close, "clicked", equalizerwin_close_cb, NULL );
 
-    equalizerwin_shade =
-        create_pbutton_ex(&equalizerwin_wlist, equalizerwin_bg,
-                          SKINNED_WINDOW(equalizerwin)->gc, 254, 3, 9, 9, 254, 137, 1, 38,
-                          equalizerwin_shade_toggle, NULL, SKIN_EQMAIN, SKIN_EQ_EX);
-    equalizerwin_shade->pb_allow_draw = FALSE;
-    ui_skinned_window_widgetlist_associate(equalizerwin, 
-        WIDGET(equalizerwin_shade));
+    equalizerwin_shade = ui_skinned_button_new();
+    ui_skinned_push_button_setup(equalizerwin_shade, SKINNED_WINDOW(equalizerwin)->fixed,
+                                 254, 3, 9, 9, 254, 137, 1, 38, SKIN_EQMAIN);
+    ui_skinned_button_set_skin_index2(equalizerwin_shade, SKIN_EQ_EX);
+    g_signal_connect(equalizerwin_shade, "clicked", equalizerwin_shade_toggle, NULL );
 
-    equalizerwin_graph =
-        create_eqgraph(&equalizerwin_wlist, equalizerwin_bg,
-                       SKINNED_WINDOW(equalizerwin)->gc, 86, 17);
-    ui_skinned_window_widgetlist_associate(equalizerwin, 
-        WIDGET(equalizerwin_graph));
+    equalizerwin_graph = ui_skinned_equalizer_graph_new(SKINNED_WINDOW(equalizerwin)->fixed, 86, 17);
 
-    equalizerwin_preamp =
-        create_eqslider(&equalizerwin_wlist, equalizerwin_bg,
-                        SKINNED_WINDOW(equalizerwin)->gc, 21, 38);
-    eqslider_set_position(equalizerwin_preamp, cfg.equalizer_preamp);
-    ui_skinned_window_widgetlist_associate(equalizerwin, 
-        WIDGET(equalizerwin_preamp));
+    equalizerwin_preamp = ui_skinned_equalizer_slider_new(SKINNED_WINDOW(equalizerwin)->fixed, 21, 38);
+    ui_skinned_equalizer_slider_set_position(equalizerwin_preamp, cfg.equalizer_preamp);
 
     for (i = 0; i < 10; i++) {
         equalizerwin_bands[i] =
-            create_eqslider(&equalizerwin_wlist, equalizerwin_bg,
-                            SKINNED_WINDOW(equalizerwin)->gc, 78 + (i * 18), 38);
-        eqslider_set_position(equalizerwin_bands[i], cfg.equalizer_bands[i]);
-        ui_skinned_window_widgetlist_associate(equalizerwin, 
-	    WIDGET(equalizerwin_bands[i]));
+            ui_skinned_equalizer_slider_new(SKINNED_WINDOW(equalizerwin)->fixed, 78 + (i * 18), 38);
+        ui_skinned_equalizer_slider_set_position(equalizerwin_bands[i], cfg.equalizer_bands[i]);
     }
 
     equalizerwin_volume =
-        create_hslider(&equalizerwin_wlist, equalizerwin_bg,
-                       SKINNED_WINDOW(equalizerwin)->gc, 61, 4, 97, 8, 1, 30, 1, 30, 3, 7,
-                       4, 61, 0, 94, equalizerwin_volume_frame_cb,
-                       equalizerwin_volume_motion_cb,
-                       equalizerwin_volume_release_cb, SKIN_EQ_EX);
-    ui_skinned_window_widgetlist_associate(equalizerwin, 
-        WIDGET(equalizerwin_volume));
+        ui_skinned_horizontal_slider_new(SKINNED_WINDOW(equalizerwin)->fixed,
+                                         61, 4, 97, 8, 1, 30, 1, 30, 3, 7, 4, 61, 0, 94,
+                                         equalizerwin_volume_frame_cb, SKIN_EQ_EX);
+    g_signal_connect(equalizerwin_volume, "motion", G_CALLBACK(equalizerwin_volume_motion_cb), NULL);
+    g_signal_connect(equalizerwin_volume, "release", G_CALLBACK(equalizerwin_volume_release_cb), NULL);
+
 
     equalizerwin_balance =
-        create_hslider(&equalizerwin_wlist, equalizerwin_bg,
-                       SKINNED_WINDOW(equalizerwin)->gc, 164, 4, 42, 8, 11, 30, 11, 30, 3,
-                       7, 4, 164, 0, 39, equalizerwin_balance_frame_cb,
-                       equalizerwin_balance_motion_cb,
-                       equalizerwin_balance_release_cb, SKIN_EQ_EX);
-    ui_skinned_window_widgetlist_associate(equalizerwin, 
-        WIDGET(equalizerwin_balance));
-
-    if (!cfg.equalizer_shaded) {
-        widget_hide(WIDGET(equalizerwin_volume));
-        widget_hide(WIDGET(equalizerwin_balance));
-    }
-    else {
-        pbutton_set_button_data(equalizerwin_shade, -1, 3, -1, 47);
-        pbutton_set_skin_index1(equalizerwin_shade, SKIN_EQ_EX);
-        pbutton_set_button_data(equalizerwin_close, 11, 38, 11, 47);
-        pbutton_set_skin_index(equalizerwin_close, SKIN_EQ_EX);
-    }
+        ui_skinned_horizontal_slider_new(SKINNED_WINDOW(equalizerwin)->fixed,
+                       164, 4, 42, 8, 11, 30, 11, 30, 3, 7, 4, 164, 0, 39,
+                       equalizerwin_balance_frame_cb, SKIN_EQ_EX);
+    g_signal_connect(equalizerwin_balance, "motion", G_CALLBACK(equalizerwin_balance_motion_cb), NULL);
+    g_signal_connect(equalizerwin_balance, "release", G_CALLBACK(equalizerwin_balance_release_cb), NULL);
 }
 
 
@@ -739,20 +531,20 @@ equalizerwin_create_window(void)
     GdkPixbuf *icon;
     gint width, height;
 
-    equalizerwin = ui_skinned_window_new(GTK_WINDOW_TOPLEVEL, "equalizer");
-    gtk_window_set_title(GTK_WINDOW(equalizerwin), _("Audacious Equalizer"));
-    gtk_window_set_role(GTK_WINDOW(equalizerwin), "equalizer");
-
     width = 275;
     height = cfg.equalizer_shaded ? 14 : 116;
 
+    equalizerwin = ui_skinned_window_new("equalizer");
+    gtk_window_set_title(GTK_WINDOW(equalizerwin), _("Audacious Equalizer"));
+    gtk_window_set_role(GTK_WINDOW(equalizerwin), "equalizer");
+    gtk_window_set_resizable(GTK_WINDOW(equalizerwin), FALSE);
+
     if (cfg.doublesize && cfg.eq_doublesize_linked) {
         width *= 2;
         height *= 2;
     }
 
-    gtk_window_set_default_size(GTK_WINDOW(equalizerwin), width, height);
-    gtk_window_set_resizable(GTK_WINDOW(equalizerwin), FALSE);
+    gtk_widget_set_size_request(equalizerwin, width, height);
 
     /* this will hide only mainwin. it's annoying! yaz */
     gtk_window_set_transient_for(GTK_WINDOW(equalizerwin),
@@ -775,20 +567,8 @@ equalizerwin_create_window(void)
                      G_CALLBACK(equalizerwin_press), NULL);
     g_signal_connect(equalizerwin, "button_release_event",
                      G_CALLBACK(equalizerwin_release), NULL);
-    g_signal_connect(equalizerwin, "motion_notify_event",
-                     G_CALLBACK(equalizerwin_motion), NULL);
-    g_signal_connect_after(equalizerwin, "focus_in_event",
-                           G_CALLBACK(equalizerwin_focus_in), NULL);
-    g_signal_connect_after(equalizerwin, "focus_out_event",
-                           G_CALLBACK(equalizerwin_focus_out), NULL);
-    g_signal_connect(equalizerwin, "configure_event",
-                     G_CALLBACK(equalizerwin_configure), NULL);
-    g_signal_connect(equalizerwin, "style_set",
-                     G_CALLBACK(equalizerwin_set_back_pixmap), NULL);
     g_signal_connect(equalizerwin, "key_press_event",
                      G_CALLBACK(equalizerwin_keypress), NULL);
-    g_signal_connect(equalizerwin, "scroll_event",
-                     G_CALLBACK(equalizerwin_scroll), NULL);
 }
 
 void
@@ -801,17 +581,7 @@ equalizerwin_create(void)
 
     gtk_window_add_accel_group( GTK_WINDOW(equalizerwin) , ui_manager_get_accel_group() );
 
-    equalizerwin_bg = gdk_pixmap_new(equalizerwin->window, 275, 116, -1);
-    equalizerwin_bg_x2 = gdk_pixmap_new(equalizerwin->window, 550, 232, -1);
-
     equalizerwin_create_widgets();
-
-    equalizerwin_set_back_pixmap();
-    if (cfg.doublesize && cfg.eq_doublesize_linked)
-        gdk_window_set_back_pixmap(equalizerwin->window,
-                                   equalizerwin_bg_x2, 0);
-    else
-        gdk_window_set_back_pixmap(equalizerwin->window, equalizerwin_bg, 0);
 }
 
 
@@ -838,12 +608,22 @@ equalizerwin_real_show(void)
     else
         gtk_widget_set_size_request(equalizerwin, 275,
                                     (cfg.equalizer_shaded ? 14 : 116));
-    gdk_flush();
-    draw_equalizer_window(TRUE);
     cfg.equalizer_visible = TRUE;
-    tbutton_set_toggled(mainwin_eq, TRUE);
+    UI_SKINNED_BUTTON(mainwin_eq)->inside = TRUE;
+    gtk_widget_show_all(equalizerwin);
 
-    gtk_widget_show(equalizerwin);
+    if (!cfg.equalizer_shaded) {
+        gtk_widget_hide(equalizerwin_volume);
+        gtk_widget_hide(equalizerwin_balance);
+    }
+    else {
+        ui_skinned_set_push_button_data(equalizerwin_shade, -1, 3, -1, 47);
+        ui_skinned_button_set_skin_index1(equalizerwin_shade, SKIN_EQ_EX);
+        ui_skinned_set_push_button_data(equalizerwin_close, 11, 38, 11, 47);
+        ui_skinned_button_set_skin_index(equalizerwin_close, SKIN_EQ_EX);
+    }
+
+    gtk_window_present(GTK_WINDOW(equalizerwin));
 }
 
 void
@@ -855,7 +635,8 @@ equalizerwin_real_hide(void)
      */
     gtk_widget_hide(equalizerwin);
     cfg.equalizer_visible = FALSE;
-    tbutton_set_toggled(mainwin_eq, FALSE);
+    UI_SKINNED_BUTTON(mainwin_eq)->inside = FALSE;
+    gtk_widget_queue_draw(mainwin_eq);
 }
 
 static EqualizerPreset *
@@ -912,9 +693,9 @@ equalizerwin_load_preset(GList * list, const gchar * name)
     gint i;
 
     if ((preset = equalizerwin_find_preset(list, name)) != NULL) {
-        eqslider_set_position(equalizerwin_preamp, preset->preamp);
+        ui_skinned_equalizer_slider_set_position(equalizerwin_preamp, preset->preamp);
         for (i = 0; i < 10; i++)
-            eqslider_set_position(equalizerwin_bands[i], preset->bands[i]);
+            ui_skinned_equalizer_slider_set_position(equalizerwin_bands[i], preset->bands[i]);
         equalizerwin_eq_changed();
         return TRUE;
     }
@@ -934,9 +715,9 @@ equalizerwin_save_preset(GList * list, const gchar * name,
         list = g_list_append(list, preset);
     }
 
-    preset->preamp = eqslider_get_position(equalizerwin_preamp);
+    preset->preamp = ui_skinned_equalizer_slider_get_position(equalizerwin_preamp);
     for (i = 0; i < 10; i++)
-        preset->bands[i] = eqslider_get_position(equalizerwin_bands[i]);
+        preset->bands[i] = ui_skinned_equalizer_slider_get_position(equalizerwin_bands[i]);
 
     equalizerwin_write_preset_file(list, filename);
 
@@ -999,9 +780,9 @@ equalizerwin_delete_selected_presets(GtkTreeView *view, gchar *filename)
 
         gtk_tree_model_get(model, &iter, 0, &text, -1);
 
-        if (filename == "eq.preset")
+        if (!strcmp(filename, "eq.preset"))
             equalizer_presets = equalizerwin_delete_preset(equalizer_presets, text, filename);
-        else if (filename == "eq.auto_preset")
+        else if (!strcmp(filename, "eq.auto_preset"))
             equalizer_auto_presets = equalizerwin_delete_preset(equalizer_auto_presets, text, filename);
 
         gtk_list_store_remove(GTK_LIST_STORE(model), &iter);
@@ -1055,11 +836,11 @@ equalizerwin_read_winamp_eqf(VFSFile * file)
         if (vfs_fread(bands, 1, 11, file) != 11)
             return;
 
-        eqslider_set_position(equalizerwin_preamp,
+        ui_skinned_equalizer_slider_set_position(equalizerwin_preamp,
                               20.0 - ((bands[10] * 40.0) / 63.0));
 
         for (i = 0; i < 10; i++)
-            eqslider_set_position(equalizerwin_bands[i],
+            ui_skinned_equalizer_slider_set_position(equalizerwin_bands[i],
                                   20.0 - ((bands[i] * 40.0) / 64.0));
     }
 
@@ -1073,12 +854,12 @@ equalizerwin_read_bmp_preset(RcFile * rcfile)
     gint i;
 
     if (bmp_rcfile_read_float(rcfile, "Equalizer preset", "Preamp", &val))
-        eqslider_set_position(equalizerwin_preamp, val);
+        ui_skinned_equalizer_slider_set_position(equalizerwin_preamp, val);
     for (i = 0; i < 10; i++) {
         gchar tmp[7];
         g_snprintf(tmp, sizeof(tmp), "Band%d", i);
         if (bmp_rcfile_read_float(rcfile, "Equalizer preset", tmp, &val))
-            eqslider_set_position(equalizerwin_bands[i], val);
+            ui_skinned_equalizer_slider_set_position(equalizerwin_bands[i], val);
     }
     equalizerwin_eq_changed();
 }
@@ -1283,13 +1064,13 @@ save_preset_file(const gchar * filename)
 
     rcfile = bmp_rcfile_new();
     bmp_rcfile_write_float(rcfile, "Equalizer preset", "Preamp",
-                           eqslider_get_position(equalizerwin_preamp));
+                           ui_skinned_equalizer_slider_get_position(equalizerwin_preamp));
 
     for (i = 0; i < 10; i++) {
         gchar tmp[7];
         g_snprintf(tmp, sizeof(tmp), "Band%d", i);
         bmp_rcfile_write_float(rcfile, "Equalizer preset", tmp,
-                               eqslider_get_position(equalizerwin_bands[i]));
+                               ui_skinned_equalizer_slider_get_position(equalizerwin_bands[i]));
     }
 
     bmp_rcfile_write(rcfile, filename);
@@ -1320,8 +1101,8 @@ save_winamp_file(const gchar * filename)
     vfs_fwrite(name, 1, 257, file);
 
     for (i = 0; i < 10; i++)
-        bands[i] = 63 - (((eqslider_get_position(equalizerwin_bands[i]) + 20) * 63) / 40);
-    bands[10] = 63 - (((eqslider_get_position(equalizerwin_preamp) + 20) * 63) / 40);
+        bands[i] = 63 - (((ui_skinned_equalizer_slider_get_position(equalizerwin_bands[i]) + 20) * 63) / 40);
+    bands[10] = 63 - (((ui_skinned_equalizer_slider_get_position(equalizerwin_preamp) + 20) * 63) / 40);
     vfs_fwrite(bands, 1, 11, file);
 
     vfs_fclose(file);
@@ -1484,7 +1265,7 @@ equalizerwin_load_auto_preset(const gchar * filename)
 void
 equalizerwin_set_preamp(gfloat preamp)
 {
-    eqslider_set_position(equalizerwin_preamp, preamp);
+    ui_skinned_equalizer_slider_set_position(equalizerwin_preamp, preamp);
     equalizerwin_eq_changed();
 }
 
@@ -1492,20 +1273,20 @@ void
 equalizerwin_set_band(gint band, gfloat value)
 {
     g_return_if_fail(band >= 0 && band < 10);
-    eqslider_set_position(equalizerwin_bands[band], value);
+    ui_skinned_equalizer_slider_set_position(equalizerwin_bands[band], value);
 }
 
 gfloat
 equalizerwin_get_preamp(void)
 {
-    return eqslider_get_position(equalizerwin_preamp);
+    return ui_skinned_equalizer_slider_get_position(equalizerwin_preamp);
 }
 
 gfloat
 equalizerwin_get_band(gint band)
 {
-    g_return_val_if_fail(band >= 0 && band < 10, 0);
-    return eqslider_get_position(equalizerwin_bands[band]);
+    g_return_val_if_fail(band >= 0 && band < 10, 0.0);
+    return ui_skinned_equalizer_slider_get_position(equalizerwin_bands[band]);
 }
 
 void
@@ -1552,10 +1333,10 @@ void
 action_equ_zero_preset(void)
 {
     gint i;
-    
-    eqslider_set_position(equalizerwin_preamp, 0);
+
+    ui_skinned_equalizer_slider_set_position(equalizerwin_preamp, 0);
     for (i = 0; i < 10; i++)
-        eqslider_set_position(equalizerwin_bands[i], 0);
+        ui_skinned_equalizer_slider_set_position(equalizerwin_bands[i], 0);
 
     equalizerwin_eq_changed();
 }
@@ -1737,3 +1518,13 @@ action_equ_delete_auto_preset(void)
                                     G_CALLBACK(equalizerwin_delete_auto_delete),
                                     NULL);
 }
+
+void
+equalizer_activate(gboolean active)
+{
+    cfg.equalizer_active = active;
+    UI_SKINNED_BUTTON(equalizerwin_on)->inside = active;
+    gtk_widget_queue_draw(equalizerwin_on);
+
+    equalizerwin_eq_changed();
+}
